==> libreoffice-still-sdk-24.8.5-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.js <==
var interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings =
[
    [ "XPropertySet", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "Addin", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a7e25321e1343c0d7c61b05f2ff099575", null ],
    [ "AutoCorrect", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3e2f548a8b28bfb3a848d12c9f7bed57", null ],
    [ "AutoText", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3d968a5faf7b851908d0322f78fdd039", null ],
    [ "Backup", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a2527e2ff0473efad64c3edc9cf77179d", null ],
    [ "BasePathShareLayer", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#acaecfd22ee1d8b84945011e6435aec89", null ],
    [ "BasePathUserLayer", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a6faf9835282e40b95c6207729c8529b7", null ],
    [ "Basic", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a721a3ca048d7eaeddd21b2925fb1d0e1", null ],
    [ "Bitmap", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a23c4df96d2453ab1ce7551835e118704", null ],
    [ "Config", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#aceaf987a0541c7621bb2119d18b7958c", null ],
    [ "Dictionary", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a7dc0c086c428bfdd85957381e88d735a", null ],
    [ "Favorite", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#aa66bcf2003e3cb8c695cfa9d8464d389", null ],
    [ "Filter", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a36e60b26868092e2acd03532c3dc0549", null ],
    [ "Gallery", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#afd11e57cea6640361af6a23a46687fd0", null ],
    [ "Graphic", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a7823c8969e3bf519a5a4763d62674175", null ],
    [ "Help", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a21653f2cfc732a330302490b0d729509", null ],
    [ "Linguistic", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a719709df798a79ef183c40b3242cb33e", null ],
    [ "Module", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#ac21f622c192284f5f23a8eee1b0710fe", null ],
    [ "Palette", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3301864cca4b54784128f9c16d4a1294", null ],
    [ "Plugin", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3178be745b5dec354ae3bf88caf94170", null ],
    [ "Storage", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3ee6a14892709eb7acdf56afb3a18c77", null ],
    [ "Temp", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a0a2d508c008f7267ea26de28f5bc7e7c", null ],
    [ "Template", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a5b6ed5b7cf2b4c06fcab23ae89e90697", null ],
    [ "UIConfig", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a5ac88e9e2d4eee538f4c4772adc806a7", null ],
    [ "UserConfig", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#afb12e1d5df0ae729c917a8e574c161cc", null ],
    [ "UserDictionary", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3bdcbc07155f7acfa57223e525e69bae", null ],
    [ "Work", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a7c4003e765d5a5230ef7b82fa369d5dd", null ]
];

==> libreoffice-still-sdk-25.2.7-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.js <==
var interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings =
[
    [ "com::sun::star::beans::XPropertySet", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "Addin", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a7e25321e1343c0d7c61b05f2ff099575", null ],
    [ "AutoCorrect", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3e2f548a8b28bfb3a848d12c9f7bed57", null ],
    [ "AutoText", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3d968a5faf7b851908d0322f78fdd039", null ],
    [ "Backup", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a2527e2ff0473efad64c3edc9cf77179d", null ],
    [ "BasePathShareLayer", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#acaecfd22ee1d8b84945011e6435aec89", null ],
    [ "BasePathUserLayer", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a6faf9835282e40b95c6207729c8529b7", null ],
    [ "Basic", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a721a3ca048d7eaeddd21b2925fb1d0e1", null ],
    [ "Bitmap", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a23c4df96d2453ab1ce7551835e118704", null ],
    [ "Config", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#aceaf987a0541c7621bb2119d18b7958c", null ],
    [ "Dictionary", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a7dc0c086c428bfdd85957381e88d735a", null ],
    [ "Favorite", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#aa66bcf2003e3cb8c695cfa9d8464d389", null ],
    [ "Filter", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a36e60b26868092e2acd03532c3dc0549", null ],
    [ "Gallery", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#afd11e57cea6640361af6a23a46687fd0", null ],
    [ "Graphic", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a7823c8969e3bf519a5a4763d62674175", null ],
    [ "Help", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a21653f2cfc732a330302490b0d729509", null ],
    [ "Linguistic", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a719709df798a79ef183c40b3242cb33e", null ],
    [ "Module", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#ac21f622c192284f5f23a8eee1b0710fe", null ],
    [ "Palette", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3301864cca4b54784128f9c16d4a1294", null ],
    [ "Plugin", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3178be745b5dec354ae3bf88caf94170", null ],
    [ "Storage", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3ee6a14892709eb7acdf56afb3a18c77", null ],
    [ "Temp", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a0a2d508c008f7267ea26de28f5bc7e7c", null ],
    [ "Template", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a5b6ed5b7cf2b4c06fcab23ae89e90697", null ],
    [ "UIConfig", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a5ac88e9e2d4eee538f4c4772adc806a7", null ],
    [ "UserConfig", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#afb12e1d5df0ae729c917a8e574c161cc", null ],
    [ "UserDictionary", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a3bdcbc07155f7acfa57223e525e69bae", null ],
    [ "Work", "interfacecom_1_1sun_1_1star_1_1util_1_1XPathSettings.html#a7c4003e765d5a5230ef7b82fa369d5dd", null ]
];
